import logging
import time
from loguru import logger

import pytest
from selenium import webdriver
from selenium.webdriver import ActionChains
from selenium.webdriver.common.by import By

from BasePage.BasePage import BasePage
from Pages.login_page import LoginPage
from Util.Util import DriverUtils
from selenium.webdriver.remote.webelement import WebElement

from Util.handle_path import log_path

# 配置日志输出格式和文件
logger.add(sink=log_path,encoding="UTF-8",level="INFO",rotation="10MB",retention=20,format="{time} - {level} - {message}")

"""
企业知识库--页面操作
"""
class BusinessKnowledgePage(BasePage):

    def __init__(self):
        super().__init__()
        self.upload_document_helper = UploadDocumentHelper()
        self.document_list_helper = DocumentListControlHelper()
        self.document_dialogue_helper = DocumentDialogueHelper()
        self.ai_editing = (By.XPATH, '//*[@id="App"]/div/header/div[2]/div[2]')  # AI编辑工作室按钮
        self.business_knowledge = (By.XPATH, '//*[@id="App"]/div/div/div[2]/ul/li[3]/div/div/span')  # 企业知识库按钮
        self.quit = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[1]/div[1]/button/span')  # 返回

        self.folders = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[2]')  # 文件夹列表
        self.newFolder = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/button[2]/span')  # 新建文件夹
        self.folderName = (By.XPATH, '//*[@id="folderName"]')  # 输入文件夹名

        self.select_folder = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[2]/div[@class="Catalog-item active"]/span')

        self.ensure = (By.XPATH, '/html/body/div[3]/div/div[2]/div/div[2]/div[3]/button[2]/span')  # 确定按钮
        self.more = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[2]/div[3]/i')  # 更多
        self.updateFolderName = (By.XPATH, '/html/body/div[3]/div/div/ul/li[1]/span/div')  # 修改名称
        self.deleteFolder = (By.XPATH, '/html/body/div[3]/div/div/ul/li[2]/span/div')  # 删除
        self.ensureDelete = (By.XPATH, '/html/body/div[4]/div/div[2]/div/div[2]/div[3]/button[2]/span')  # 确认

        self.moreFolderName = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[2]/div[3]/span')

        self.searchInputText = (
            By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/div[1]/span/input')  # 搜索文本框
        self.subscriptionWebsiteButton = (
            By.XPATH, '//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[1]/button[1]')  # 订阅网站
        self.updateWebsiteFrequencySelect = (
            By.XPATH, '/html/body/div[3]/div/div[2]/div/div[2]/div[2]/div/form/div[2]/div/div[2]/div/div/div')  # 更新网站频率
        self.updateWebsiteFrequencyDataDiv = (By.XPATH, '/html/body/div[4]/div/div/div/div[2]/div[1]/div/div')  # 更新频率数据

        # 订阅网站列表
        self.subscriptionWebsiteListDiv = (By.XPATH, '//*[@id="website"]/div/div[2]/div[1]')
        # 确定订阅
        self.ensureSubscriptionWebsite = (By.XPATH, '/html/body/div[3]/div/div[2]/div/div[2]/div[3]/div/button[2]/span')
        # 清空
        self.clearButton = (By.XPATH, '//*[@id="website"]/div/div[1]/span[2]/span[2]')
        # 去除
        self.removeButton = (By.XPATH, '//*[@id="website"]/div/div[2]/div[2]/div[1]/div/div[1]/div[2]')


    """
    通用
    """

    # 进入AI编辑工作室
    def entranceAi(self):
        self.find_el(self.ai_editing).click()

    # 进入企业知识库
    def entranceBusinessKnowledge(self):
        self.find_el(self.business_knowledge).click()

    # 返回/首页 退出
    def quitBusinessKnowledge(self):
        self.find_el(self.quit).click()

    """
    文件夹管理
    """

    # 新建文件夹操作 输入长度测试点
    def newFolderControl(self, folderNameInput=None):
        self.find_el(self.newFolder).click()  # 弹出输入框
        self.input_text_by_loc(self.folderName, folderNameInput)  # 输入文件夹名称
        self.find_el(self.ensure).click()  # 点击确认

    # 删除文件夹
    def deleteFolderControl(self):
        self.find_el(self.more).click()  # 点击更多
        time.sleep(1)
        self.find_el(self.deleteFolder).click()  # 弹出二次删除弹框
        time.sleep(1)
        self.find_el(self.ensureDelete).click()  # 点击确认删除

    # 修改文件夹
    def updateFolderControl(self, updateFolderName=None):
        self.find_el(self.more).click()  # 点击更多
        time.sleep(1)
        self.find_el(self.updateFolderName).click()  # 弹出修改弹框
        self.input_text_by_loc(self.folderName, updateFolderName)
        time.sleep(1)
        self.find_el(self.ensureDelete).click()  # 点击确认
        time.sleep(1)
        # 返回修改后的文件名
        return self.get_text_loc(self.moreFolderName)


    # 遍历点击文件夹
    def traverseFolder(self):
        elementSpans = self.find_el(self.folders).find_elements('tag name', 'span')
        for elementSpan in elementSpans:
            elementSpan.click()
            time.sleep(2)

    """
    搜索文档
    """

    # 搜索
    def searchDocument(self, keyName=None):
        self.input_text_by_loc(self.searchInputText, keyName)
        time.sleep(2)
        # 返回搜索到的所有文档
        folders = self.find_el(self.folders).find_elements(By.XPATH,"./div")
        documents = []
        for folder in folders:
            folder.click()
            time.sleep(1)
            # 获取所有文档
            documentStep = self.find_el(self.document_list_helper.documentListDiv).find_elements(By.XPATH,"./tr")
            documents.extend(documentStep)
        print(documents)
        return documents

    # 判断这些文档中是否存在某些关键词
    def isExistKeyInDocument(self,key_name=None,documents=None):
        flag = True
        for document in documents:
            actual_document_name = document.find_element(By.XPATH,"./td[2]/div/div").get_attribute("title")
            if not actual_document_name.find(key_name):
                flag = False
                logger.info("搜索失败，搜索出额外文档")
                return flag
        return flag



    """
    网站订阅
    """

    # 点击订阅网站 弹出弹框
    def subscriptionWebsiteStart(self):
        self.find_el(self.subscriptionWebsiteButton).click()

    # 订阅频率选中-根据optionName进行选中
    def subscriptionWebsiteFrequencySelect(self, optionName=None):
        self.find_el(self.updateWebsiteFrequencySelect).click()  # 点击更新频率
        time.sleep(2)
        # 获取到全部数据
        elementsFrequencyOptions = self.find_el(self.updateWebsiteFrequencyDataDiv).find_elements(By.XPATH, '/html/body/div[4]/div/div/div/div[2]/div[1]/div/div/div[contains(@class, "ant-select-item")]')
        # 订阅频率选择
        for elementsFrequencyOption in elementsFrequencyOptions:
            # 模拟鼠标悬停到选项上
            ActionChains(driver).move_to_element(elementsFrequencyOption).perform()
            time.sleep(1)
            # 模拟点击选项
            if optionName == elementsFrequencyOption.text:
                logger.info(f"选择的更新频率{elementsFrequencyOption}")
                elementsFrequencyOption.click()
                break

    # 选中订阅的网站
    def subscriptionWebsiteSelect(self, optionsName=None):
        print(optionsName)
        subscriptionWebsiteOptions = self.find_el(self.subscriptionWebsiteListDiv).find_elements(By.XPATH,'//*[@id="website"]/div/div[2]/div[1]/div[contains(@class,"website-item")]')
        subscriptionWebsiteOptionTexts = self.find_el(self.subscriptionWebsiteListDiv).find_elements(By.XPATH,'//*[@id="website"]/div/div[2]/div[1]/div/label/span[2]/div/div/div')
        time.sleep(1)
        for subscriptionWebsiteOption,subscriptionWebsiteOptionText in zip(subscriptionWebsiteOptions,subscriptionWebsiteOptionTexts):
            for optionName in optionsName:
                if optionName == subscriptionWebsiteOptionText.text:
                    logger.info(f"选择的网站:{subscriptionWebsiteOptionText.text}")
                    subscriptionWebsiteOption.click()  # 选中

    # 清空网站订阅内容
    def clearSubscriptionWebsite(self):
        self.find_el(self.clearButton).click()

    # 移除订阅的网站
    def removeSubscriptionWebsite(self,count=None):
        for i in range(count):

            self.find_el(self.removeButton).click()

    # 确定订阅网站
    def ensureSubscriptionWebsite(self):
        self.find_el(self.ensureSubscriptionWebsite).click()

    # 网站订阅-整个流程
    def subscriptionWebsite(self):
        self.find_el(self.subscriptionWebsiteButton).click()  # 点击订阅网站 弹出弹框
        time.sleep(2)
        self.find_el(self.updateWebsiteFrequencySelect).click()  # 点击更新频率
        time.sleep(2)
        # 获取到全部数据
        elementsFrequencyOptions = self.find_el(self.updateWebsiteFrequencyDataDiv).find_elements(By.XPATH,
                                                                                                  '/html/body/div[4]/div/div/div/div[2]/div[1]/div/div/div[contains(@class, "ant-select-item")]')
        count = 0
        # 订阅频率选择
        for elementsFrequencyOption in elementsFrequencyOptions:
            # time.sleep(1)
            # self.find_el(self.updateWebsiteFrequencySelect).click()  # 点击更新频率
            # time.sleep(1)
            # 模拟鼠标悬停到选项上
            ActionChains(driver).move_to_element(elementsFrequencyOption).perform()
            time.sleep(1)
            count = count + 1
            # 模拟点击选项
            if (count == len(elementsFrequencyOptions)):
                elementsFrequencyOption.click()
        # 选择订阅的网站
        subscriptionWebsiteOptions = self.find_el(self.subscriptionWebsiteListDiv).find_elements(By.XPATH,
                                                                                                 '//*[@id="website"]/div/div[2]/div[1]/div[contains(@class,"website-item")]')
        for subscriptionWebsiteOption in subscriptionWebsiteOptions:
            subscriptionWebsiteOption.click()  # 选中
        # 确定订阅
        self.find_el(self.ensureSubscriptionWebsite).click()



    """
    上传文档-三种方式
    """
class UploadDocumentHelper(BasePage):
    def __init__(self):
        super().__init__()
        self.uploadDocumentButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[2]/div[1]')  # 上传文档按钮
        self.pasteTextButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[2]/div[2]')  # 粘贴文本
        self.importWebsiteButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[2]/div[3]')  # 导入网站

        self.clickUploadButton = (By.XPATH,'/html/body/div[3]/div/div[2]/div/div[2]/div[2]/div/div[2]/div[2]/div[1]/div')  # 点击上传

        self.titleText = (By.XPATH,'//*[@id="docName"]')  # 文档名称
        self.contentText = (By.XPATH,'//*[@id="content"]') # 文档内容
        self.ensureButton = (By.XPATH,'/html/body/div[3]/div/div[2]/div/div[2]/div[3]/div/button[2]')  # 确定

        self.urlText = (By.XPATH,'//*[@id="url"]')
        self.getContentButtons = (By.CLASS_NAME,'btn-wrap')

    """
    方式一：上传文档
    文档类型
    文档大小
    """
    def uploadDocumentControl(self,str_paths=None):

        time.sleep(1)
        for str_path in str_paths:
            time.sleep(1)
            self.find_el(self.uploadDocumentButton).click()  # 点击 弹出弹窗
            logging.info(str_path)
            time.sleep(1)
            self.find_el(self.clickUploadButton).click()  # 弹窗，选择文件
            self.select_document(str_path)
            time.sleep(1)

    """
    粘贴文本
    """
    def pasteTextControl(self,title=None,content=None):
        self.find_el(self.pasteTextButton).click()
        self.input_text_by_loc(self.titleText,title)
        self.input_text_by_loc(self.contentText,content)
        self.find_el(self.ensureButton).click()

    """
    导入网站
    """
    def uploadUrlControl(self,url_link=None):
        self.find_el(self.importWebsiteButton).click()
        time.sleep(1)
        self.input_text_by_loc(self.urlText,url_link)
        time.sleep(2)
        buttons = self.find_el(self.getContentButtons).find_elements(By.XPATH,"./button")
        buttons[1].click()
        time.sleep(4)


"""
   文档列表操作 对话操作 删除操作 更多【修改名称、复制、移动到】
"""
class DocumentListControlHelper(BasePage):
    def __init__(self):
        super().__init__()
        # 获取文档内容--此处获取的是一页的全部列表
        self.documentListDiv = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[3]/div/div/div/div/div/div/div/table/tbody')
        self.documentDiv = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[3]/div/div/div/div/div/div/div/table/tbody/tr')
        self.documentDeleteButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[3]/div/div/div/div/div/div/div/table/tbody//button[.//span[text()="删除"]]')
        self.modelFooter = (By.CLASS_NAME,"ant-modal-footer")  # 对于此块代码 无法通过xpath获取
        self.modalBody = (By.CLASS_NAME,"ant-modal-body") # 对于此块代码 无法通过xpath获取
        self.quit = (By.XPATH, '//*[@id="App"]/div/section/div[1]/div[1]/div[1]/button/span')  # 返回
        self.statusStudy = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[3]/div/div/div/div/div/div/div/table/tbody/tr/td[3]/div')
        self.documentDialogueButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[3]/div/div/div/div/div/div/div/table/tbody//span[text()="对话"]')
        self.moreButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[3]/div/div/div/div/div/div/div/table/tbody/tr[1]/td[5]/div/span/label/button')
        # self.documents = self.find_son_elements(self.find_el(self.documentListDiv), self.documentDiv)

        self.controlList = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[3]/div/div/div/div/div/div/div/table/tbody/tr[1]/td[5]/div/span/ul')
        self.firstDocument = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[2]/div[2]/div/div/div/div/div/div/div/table/tbody/tr[1]/td[3]/div/span')
    # 删除
    def documentListDeleteControl(self,count=None):
        documents = self.find_son_elements(self.find_el(self.documentListDiv), self.documentDiv)
        documents_length = len(documents)
        if count <= documents_length:
            res_count = count
        else:
            res_count = documents_length
        for i in range(res_count):
            buttons = self.find_son_elements(self.find_el(self.documentListDiv),self.documentDeleteButton)
            time.sleep(1)
            buttons[0].click()
            time.sleep(2)
            self.find_el(self.modelFooter).find_elements(By.TAG_NAME,"button")[1].click()
            logger.info("成功删除一条文档记录")
            time.sleep(1)

    # 对话
    def documentListDialogueControl(self,count=None):
        statuses = self.find_son_elements(self.find_el(self.documentListDiv),self.statusStudy)
        documents = self.find_son_elements(self.find_el(self.documentListDiv),self.documentDiv)
        documents_length = len(documents)
        if count > documents_length:
            logger.info("超过此页展示的文档")
            return
        i = 0
        for statusDiv,document in zip(statuses,documents):
            i = i + 1
            if count == i:
                status_value = statusDiv.get_attribute("class")
                logger.info(f"第{i}文档状态为:{status_value}")
                if status_value.find("success") != -1:
                    # index / in
                    logger.info("包含success") # success
                    document.find_element(By.XPATH, './/span[text()="对话"]').click()  # 点击进入文档对话 .代表当前路径 //代表隔代
                    time.sleep(2)
                    self.find_el(self.quit).click()
                    time.sleep(2)
                    logger.info("完成")
                    return
                else:
                    logger.info("不包含success 不可点击对话") # fail
                    return

    # 更多
    def more_control(self, document=None, type=None):

        if document:
            document.find_element(By.XPATH, './/span[text()="更多"]').click()
            time.sleep(2)
        else:
            logger.info("点击第一个更多")
            self.find_el(self.moreButton).click()

        if type == 1:  # 修改名称
            document.find_element(By.XPATH, './/ul/li[1]/div').click()
        elif type == 2:  # 复制
            document.find_element(By.XPATH, './/ul/li[2]/div').click()
        elif type == 3:  # 移动
            document.find_element(By.XPATH, './/ul/li[3]/div').click()
        time.sleep(2)

    # 修改名称
    def update_document_name_control(self,new_document_name=None,count=None):
        time.sleep(3)
        statuses = self.find_son_elements(self.find_el(self.documentListDiv), self.statusStudy)
        documents = self.find_son_elements(self.find_el(self.documentListDiv), self.documentDiv)
        i = 0
        for status_div,document in zip(statuses,documents):
            i = i + 1
            if count == i :
                status_value = status_div.get_attribute("class")
                if status_value.find("success") != -1:
                    logger.info("文档为success状态了")
                    self.more_control(document,1)
                    logger.info(f"第{i}个文档被点击更多-修改名称了")
                    time.sleep(1)
                    input_text = self.find_el(self.modalBody).find_element(By.XPATH,".//input[@placeholder='请输入文件名称']")
                    self.input_text_by_ele(input_text,new_document_name)
                    time.sleep(1)
                    self.find_el(self.modelFooter).find_elements(By.TAG_NAME, "button")[1].click()
                    logger.info(f"第{i}个文档修改名称完成")
                    time.sleep(2)
                else:
                    logger.info("不可点击 状态为fail 无更多按钮")

    # 复制到/移动到 type 2 3
    def copy_document_control(self, count=None, type=None, folder_name=None):
        time.sleep(3)
        statuses = self.find_son_elements(self.find_el(self.documentListDiv), self.statusStudy)
        documents = self.find_son_elements(self.find_el(self.documentListDiv), self.documentDiv)
        i = 0
        for status_div, document in zip(statuses, documents):
            i = i + 1
            if count == i:
                status_value = status_div.get_attribute("class")
                if status_value.find("success") != -1:
                    logger.info("文档为success状态了")
                    self.more_control(document, type)
                    logger.info(f"第{i}个文档被点击更多-复制/移动至了")
                    time.sleep(1)
                    catalog_items = self.find_el(self.modalBody).find_elements(By.CLASS_NAME,"Catalog-List")
                    flog = None
                    for catalog_item in catalog_items: # type: WebElement
                        reality_text_button = catalog_item.find_element(By.XPATH,'.//span')
                        reality_text = reality_text_button.get_attribute('innerText')
                        logger.info(f"真实的文件夹名:{reality_text}")
                        if reality_text == folder_name:   # 如果相同说明是需要复制到的文件夹
                            reality_text_button.click()   # 点击 选择
                            time.sleep(1)
                            self.find_el(self.modelFooter).find_elements(By.TAG_NAME, "button")[1].click()
                            flog = True
                            time.sleep(2)
                    if not flog:
                        logger.info(f"没有此文件夹名称:{folder_name}")
                        break
                    logger.info(f"第{i}个文档复制/移动完成")
                    time.sleep(2)
                else:
                    logger.info("不可点击 状态为fail 无更多按钮")


    """
    文档对话
    """


"""
文档对话
"""
class DocumentDialogueHelper(BasePage):
    def __init__(self):
        super().__init__()
        #  文件夹对话
        self.folderDialogueButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div/div[2]/div/div[1]/button')
        self.DialogueButtons = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[1]/div[2]/div[1]')
        self.sonButtons = (By.XPATH,'./div')
        #  文档搜索
        self.searchTextInput = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[1]/div[2]/div[2]/span/input')
        #  所有文档
        self.documentAllList = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[1]/div[2]/div[3]')
        #  收起
        self.xiangzuoButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[1]/div[1]/i')
        # 缩小
        self.minificationButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[2]/div/div[1]/div[2]/i[1]')
        # 放大
        self.maxficationButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[2]/div/div[1]/div[2]/i[2]')

        # 全屏
        self.fullScreenButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[2]/div/div[1]/div[2]/i[3]')
        # 下拉
        self.fangdaButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[2]/div/div[1]/div[2]/div[1]')
        self.fangdaDataList = (By.CLASS_NAME,'rc-virtual-list-holder-inner')
        #  对话 文档解读 笔记
        self.typeButtons = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/ul')
        # 推荐问题
        self.recommendButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/div[3]/span/label/div[1]/div')
        self.recommendQuestionsDataList = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/div[3]/span/ul')
        # 文档选择
        self.documentSelectButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/div[3]/div/div[1]/div/div[1]')
        self.folderListData = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/div[3]/div/div[1]/div/div[2]/div')
        # 提问文本域
        self.dialogueText = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/div[3]/div/textarea')
        # 发送按钮
        self.sendButton = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/div[3]/div/button')
        # 对话内容
        self.dialogueContent = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/div[2]')

        # 导出解读
        self.deriveDocumentSummary = (By.XPATH,'//*[@id="App"]/div/section/div[1]/div[2]/div/div[1]/div/div/div[3]/button')

    #  文件夹对话入口
    def folderDialogueControl(self):
        self.find_el(self.folderDialogueButton).click()
        time.sleep(1)

    # 文档对话和文件夹对话切换
    def toggle_document_folder_dialogue_control(self):
        eles_buttons = self.find_son_elements(self.find_el(self.DialogueButtons),self.sonButtons)
        for eles_button in eles_buttons:
            eles_button.click()
            time.sleep(1)
            text_name = eles_button.find_element(By.XPATH,".//span").get_attribute('innerText')
            logger.info(f"此时为:{text_name}")
            time.sleep(1)
    # 文档切换
    def toggle_document_control(self):
        time.sleep(1)
        documents = self.find_el(self.documentAllList).find_elements(By.XPATH,"./div")
        for document in documents:
            document.click()
            time.sleep(1)
            document_name = document.find_element(By.XPATH,"./div/span/div/span").get_attribute("innerText")
            logger.info(f"此时文档名为:{document_name}")
            time.sleep(2)

    # 搜索文档
    def search_document_control(self, key_name=None):
        eles_buttons = self.find_son_elements(self.find_el(self.DialogueButtons), self.sonButtons)
        time.sleep(1)
        eles_buttons[0].click()
        time.sleep(1)
        self.input_text_by_ele(self.find_el(self.searchTextInput),key_name)
        time.sleep(3)

    # 向左收起
    def xiangzuo_control(self):
        time.sleep(1)
        self.find_el(self.xiangzuoButton).click()
        logger.info(f"-------------收起--------")
        time.sleep(1)
        self.find_el(self.xiangzuoButton).click()
        logger.info(f"-------------收起--------")

    # 缩小 放大 全屏 1 2 3
    def document_types_control(self, type=None):
        time.sleep(1)
        if type == 1:  # 缩小
            self.find_el(self.minificationButton).click()
            logger.info(f"-------------缩小操作--------")
            time.sleep(1)
        elif type == 2:  # 放大
            self.find_el(self.maxficationButton).click()
            logger.info(f"-------------放大操作--------")
            time.sleep(1)
        elif type == 3:   # 全屏
            self.find_el(self.fullScreenButton).click()
            logger.info(f"-------------全屏操作--------")
            time.sleep(1)



    # 对话 文档解读 笔记 1 2 3
    def menu_types_control(self, type=None):
        time.sleep(1)
        menus = self.find_el(self.typeButtons).find_elements(By.XPATH,"./li")
        i = 0
        for menu in menus:
            if (type-1) == i:
                menu.click()
                menu_name = menu.find_element(By.XPATH, "./span").get_attribute("innerText")
                logger.info(f"此时菜单点击的为:{menu_name}")
                time.sleep(1)
                return
            i = i+1

    # 选择特定的放大倍数
    def select_magnification_by(self,magnification_value):
        magnification_value = str(magnification_value)+"%"
        self.find_el(self.fangdaButton).click()
        time.sleep(1)
        magnificatios = self.find_el(self.fangdaDataList).find_elements(By.XPATH,"./div")  # 获取所有的方法倍数数据
        for magnification in magnificatios:
            title_name = magnification.get_attribute("title")
            if title_name == magnification_value:
                magnification.click() # 点击完成
                logger.info(f"点击选择了{title_name}")
                return


    # 滑动查看文章内容


    """
    对话内容可：添加到笔记 复制 点赞 点踩 
    文档解读内容可：添加到笔记 复制
    笔记可：复制 删除
    添加到笔记 复制 点赞 点踩 删除
    1 2 3 4 5
    
    """
    def small_control(self, menu_type = None ):
        pass


    # 导出解读
    def derive_document_summary_control(self):
        self.menu_types_control(2)
        time.sleep(1)
        self.find_el(self.deriveDocumentSummary).click()
        logger.info("点击文档解读")



    # 导出笔记
    def derive_note_control(self):
        self.menu_types_control(3)
        time.sleep(1)
        self.find_el(self.deriveDocumentSummary).click()
        logger.info("点击导出笔记")

    # 推荐问题
    def recommend_control(self, count=None):
        time.sleep(1)
        self.find_el(self.recommendButton).click()
        time.sleep(1)
        questions = self.find_el(self.recommendQuestionsDataList).find_elements(By.XPATH,"./li")
        logger.info(f"此处有{len(questions)}个推荐问题")
        time.sleep(1)
        questions[count-1].click()
        question_name = questions[count-1].get_element(By.XPATH,"./div/span/div/span/div/span/span[2]").get_attribute("innerText")
        logger.info(f"选择的问题为{question_name}")
        time.sleep(9)

    # 切换对话的对象 文件夹/文档

    # 输入问题并点击发送
    def send_question_control(self, question=None):
        time.sleep(1)
        self.input_text_by_ele(self.find_el(self.dialogueText),question)
        time.sleep(1)
        self.find_el(self.sendButton).click()
        time.sleep(9)











if __name__ == '__main__':
    driver = DriverUtils.get_web_driver()
    driver.get('https://rays7.raysgo.com/login')
    time.sleep(1)
    LoginPage().login_username("17373027967", "3149390154Li")
    time.sleep(1)
    businessKnowledge = BusinessKnowledgePage()
    businessKnowledge.entranceAi()
    time.sleep(1)
    businessKnowledge.entranceBusinessKnowledge()
    time.sleep(1)
    businessKnowledge.document_dialogue_helper.folderDialogueControl()
    time.sleep(1)
    businessKnowledge.document_dialogue_helper.select_magnification_by("50")
    time.sleep(2)


    # businessKnowledge.document_dialogue_helper.menu_types_control(1)
    # businessKnowledge.document_dialogue_helper.toggle_document_control()
    # businessKnowledge.document_dialogue_helper.toggle_document_folder_dialogue_control()
    # businessKnowledge.document_list_helper.copy_document_control(2,"团队共享知识库")
    # businessKnowledge.document_list_helper.documentListDialogueControl(2)
    # businessKnowledge.document_list_helper.documentListControl(3)
    # businessKnowledge.upload_document_helper.uploadUrlControl("https://blog.csdn.net/FezZZZ/article/details/120878765")
    # time.sleep(2)

    # businessKnowledge.upload_document_helper.pasteTextControl("标题","内容内内容内内容内内容内内容内内容内内容内内容内内容"
    #                                                                  "内内容内内容内内容内内容内内容内内容内内容内内容内内容内"
    #                                                                  "内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内"
    #                                                                  "容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容"
    #                                                                  "内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内"
    #                                                                  "内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容"
    #                                                                  "内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容"
    #                                                                  "内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容"
    #                                                                  "内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容"
    #                                                                  "内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容"
    #                                                                  "内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内内容内")
    # time.sleep(2)

    # stry_paths = []
    # for i in range(3):
    #     stry_paths.append("t"+str(i+1)+".txt")
    # businessKnowledge.upload_document_helper.uploadDocumentControl(stry_paths)
    # time.sleep(4)


    # businessKnowledge.subscriptionWebsiteStart()
    # time.sleep(1)
    # businessKnowledge.subscriptionWebsiteFrequencySelect("三天更新一次")
    # time.sleep(1)
    # businessKnowledge.subscriptionWebsiteSelect(['出版商务周报官网','中国出版'])
    # time.sleep(2)

    # businessKnowledge.newFolderControl("文件夹名称188")
    # time.sleep(2)
    # while 1:
    #     businessKnowledge.deleteFolderControl()
    # time.sleep(2)
    # # # businessKnowledge.updateFolderControl()
    # # businessKnowledge.traverseFolder()
    # # businessKnowledge.searchDocument("1")
    # businessKnowledge.subscriptionWebsite()
    # time.sleep(2)
